summaryrefslogtreecommitdiffstats
path: root/lib/kotext/DateFormatWidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/DateFormatWidget.cpp')
-rw-r--r--lib/kotext/DateFormatWidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/kotext/DateFormatWidget.cpp b/lib/kotext/DateFormatWidget.cpp
index 0c1b3575..c93807a3 100644
--- a/lib/kotext/DateFormatWidget.cpp
+++ b/lib/kotext/DateFormatWidget.cpp
@@ -15,11 +15,11 @@
#include <KoVariable.h>
/*
* Constructs a DateFormatWidget which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'fl'
*/
-DateFormatWidget::DateFormatWidget( TQWidget* tqparent, const char* name, WFlags fl )
- : TimeDateFormatWidgetPrototype( tqparent, name, fl )
+DateFormatWidget::DateFormatWidget( TQWidget* parent, const char* name, WFlags fl )
+ : TimeDateFormatWidgetPrototype( parent, name, fl )
{
setCaption( i18n( "DateFormat", "Format of Date Variable" ) );
TQStringList listDateFormat = KoVariableDateFormat::staticTranslatedFormatPropsList();
@@ -15,11 +15,11 @@
#include <KoVariable.h>
/*
- * Constructs a DateFormatWidget which is a child of 'tqparent', with the
+ * Constructs a DateFormatWidget which is a child of 'parent', with the
* name 'name' and widget flags set to 'fl'
*/